@@ -17,7 +17,7 @@ DEVSTACK_PATH="$BASE/new"
 
 #Argument is received from Zuul
 if [ "$1" = "api" ]; then
-  TESTS="topology|test_rca|test_alarms|test_resources|test_template|test_webhook"
+  TESTS="topology|test_rca|test_alarms|test_resources|test_template|test_webhook|test_service"
 elif [ "$1" = "datasources" ]; then
   TESTS="datasources|test_events|notifiers|e2e|database"
 elif [ "$1" = "mock" ]; then
