@@ -17,21 +17,22 @@ import json
 from oslo_log import log as logging
 from testtools import matchers
 
-from vitrage.common.constants import EdgeLabel
-from vitrage.common.constants import EdgeProperties
-from vitrage.common.constants import VertexProperties as VProps
-from vitrage.datasources.aodh import AODH_DATASOURCE
-from vitrage.datasources import NOVA_HOST_DATASOURCE
-from vitrage.datasources import NOVA_INSTANCE_DATASOURCE
 from vitrage.entity_graph.mappings.operational_alarm_severity \
     import OperationalAlarmSeverity
 from vitrage.entity_graph.mappings.operational_resource_state \
     import OperationalResourceState
-from vitrage.evaluator.actions.evaluator_event_transformer \
-    import VITRAGE_DATASOURCE
 from vitrage_tempest_plugin.tests.api.alarms.base import BaseAlarmsTest
 from vitrage_tempest_plugin.tests.base import IsNotEmpty
 from vitrage_tempest_plugin.tests.common import aodh_utils
+from vitrage_tempest_plugin.tests.common.constants import AODH_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import EdgeLabel
+from vitrage_tempest_plugin.tests.common.constants import EdgeProperties
+from vitrage_tempest_plugin.tests.common.constants import NOVA_HOST_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import \
+    NOVA_INSTANCE_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import VertexProperties \
+    as VProps
+from vitrage_tempest_plugin.tests.common.constants import VITRAGE_DATASOURCE
 from vitrage_tempest_plugin.tests.common import general_utils as g_utils
 from vitrage_tempest_plugin.tests.common import nova_utils
 from vitrage_tempest_plugin.tests.common.tempest_clients import TempestClients
@@ -44,16 +45,6 @@ VITRAGE_ALARM_NAME = 'instance_deduce'
 
 class BaseRcaTest(BaseAlarmsTest):
 
-    def setUp(self):
-        super(BaseRcaTest, self).setUp()
-
-    def tearDown(self):
-        super(BaseRcaTest, self).tearDown()
-
-    @classmethod
-    def setUpClass(cls):
-        super(BaseRcaTest, cls).setUpClass()
-
     def _clean_all(self):
         nova_utils.delete_all_instances()
         aodh_utils.delete_all_aodh_alarms()
@@ -84,7 +75,7 @@ class BaseRcaTest(BaseAlarmsTest):
         parsed_rca = json.loads(cli_rca)
         sorted_cli_graph = self._clean_timestamps(sorted(parsed_rca.items()))
         sorted_api_graph = self._clean_timestamps(sorted(api_rca.items()))
-        self.assertEqual(sorted_cli_graph, sorted_api_graph)
+        self.assert_list_equal(sorted_cli_graph, sorted_api_graph)
 
     def _validate_rca(self, rca):
         self.assertThat(rca, IsNotEmpty, 'The rca is empty')
@@ -149,10 +140,11 @@ class BaseRcaTest(BaseAlarmsTest):
         for item in links:
             source_alarm_name = alarms[item['source']].get(VProps.NAME)
             target_alarm_name = alarms[item['target']].get(VProps.NAME)
-            if item.get('key') != EdgeLabel.CAUSES \
-                    or item.get(EdgeProperties.RELATIONSHIP_TYPE) != EdgeLabel.CAUSES \
-                    or source_alarm_name != RCA_ALARM_NAME \
-                    or target_alarm_name != VITRAGE_ALARM_NAME:
+            relationship_type = item.get(EdgeProperties.RELATIONSHIP_TYPE)
+            if (item.get('key') != EdgeLabel.CAUSES or
+               relationship_type != EdgeLabel.CAUSES or
+               source_alarm_name != RCA_ALARM_NAME or
+               target_alarm_name != VITRAGE_ALARM_NAME):
                 flag = False
 
         self.assertThat(alarms, matchers.HasLength(3))
