@@ -16,40 +16,29 @@ import json
 from oslo_log import log as logging
 from testtools import matchers
 
-from vitrage.common.exception import VitrageError
 from vitrage_tempest_plugin.tests.base import BaseVitrageTempest
 from vitrage_tempest_plugin.tests.base import IsNotEmpty
 from vitrage_tempest_plugin.tests.common import general_utils as g_utils
+from vitrage_tempest_plugin.tests.common.general_utils\
+    import tempest_resources_dir
 from vitrage_tempest_plugin.tests.common import vitrage_utils
 
-
 LOG = logging.getLogger(__name__)
 
 
 class BaseTemplateTest(BaseVitrageTempest):
     """Template test class for Vitrage API tests."""
 
-    TEST_PATH = '/opt/stack/vitrage/vitrage_tempest_plugin/' \
-                + 'tests/resources/templates/api/'
+    TEST_PATH = tempest_resources_dir() + '/templates/api/'
 
     NON_EXIST_FILE = 'non_exist_file.yaml'
     ERROR_FILE = 'corrupted_template.yaml'
     OK_FILE = 'nagios_alarm_for_alarms.yaml'
 
-    ERROR_STATUS = 'validation failed'
-    OK_STATUS = 'validation OK'
+    VALIDATION_FAILED = 'validation failed'
+    VALIDATION_OK = 'validation OK'
     OK_MSG = 'Template validation is OK'
 
-    def setUp(self):
-        super(BaseTemplateTest, self).setUp()
-
-    def tearDown(self):
-        super(BaseTemplateTest, self).tearDown()
-
-    @classmethod
-    def setUpClass(cls):
-        super(BaseTemplateTest, cls).setUpClass()
-
     def _compare_template_lists(self, api_templates, cli_templates):
         self.assertThat(api_templates, IsNotEmpty(),
                         'The template list taken from api is empty')
@@ -79,7 +68,7 @@ class BaseTemplateTest(BaseVitrageTempest):
         parsed_topology = json.loads(cli_templates)
         sorted_cli_templates = sorted(parsed_topology.items())
         sorted_api_templates = sorted(api_templates.items())
-        self.assertEqual(sorted_api_templates, sorted_cli_templates)
+        self.assert_list_equal(sorted_api_templates, sorted_cli_templates)
 
     def _validate_templates_list_length(self, api_templates, cli_templates):
         self.assertEqual(len(cli_templates.splitlines()),
@@ -110,23 +99,30 @@ class BaseTemplateTest(BaseVitrageTempest):
                         'The template validation is empty')
         self.assertEqual(path, validation['file path'])
         self.assertEqual(0, validation['status code'])
-        self.assertEqual(self.OK_STATUS, validation['status'])
+        self.assertEqual(self.VALIDATION_OK, validation['status'])
         self.assertEqual(self.OK_MSG, validation['message'])
         self.assertEqual(validation['message'], template['status details'])
 
-    def _run_template_validation(
-            self, validation, path, negative=False):
-        self.assertIn(path, validation['file path'])
+    def _assert_validate_result(self, validation, path, negative=False,
+                                status_code=0):
+        self.assertThat(validation['results'], matchers.HasLength(1))
+        result = validation['results'][0]
+        self.assertIn(path, result['file path'])
 
         if negative:
-            self.assertEqual(3, validation['status code'])
-            self.assertEqual(self.ERROR_STATUS, validation['status'])
-            self.assertNotEqual(validation['message'], self.OK_MSG)
+            self.assertEqual(status_code, result['status code'])
+            self.assertEqual(self.VALIDATION_FAILED, result['status'])
+            self.assertNotEqual(result['message'], self.OK_MSG)
             return
 
-        self.assertEqual(0, validation['status code'])
-        self.assertEqual(self.OK_STATUS, validation['status'])
-        self.assertEqual(self.OK_MSG, validation['message'])
+        self.assertEqual(0, result['status code'])
+        self.assertEqual(self.VALIDATION_OK, result['status'])
+        self.assertEqual(self.OK_MSG, result['message'])
+
+    def _assert_add_result(self, result, status, message):
+        self.assertThat(result, matchers.HasLength(1))
+        self.assertEqual(status, result[0]['status'])
+        self.assertEqual(message, result[0]['status details'])
 
     def _compare_template_show(self, api_templates, cli_templates):
         self.assertThat(api_templates, IsNotEmpty(),
@@ -142,12 +138,10 @@ class BaseTemplateTest(BaseVitrageTempest):
         parsed_topology = json.loads(cli_templates)
         sorted_cli_templates = sorted(parsed_topology.items())
         sorted_api_templates = sorted(api_templates.items())
-        self.assertEqual(sorted_api_templates, sorted_cli_templates)
+        self.assert_list_equal(sorted_api_templates, sorted_cli_templates)
 
-    def _rollback_to_default(self, templates):
-        try:
-            for t in templates:
-                db_row = vitrage_utils.get_first_template(name=t)
-                vitrage_utils.delete_template(db_row['uuid'])
-        except Exception as e:
-            raise VitrageError('Rollback to default failed %s', e)
+    @staticmethod
+    def _rollback_to_default(templates):
+        for t in templates:
+            db_row = vitrage_utils.get_first_template(name=t)
+            vitrage_utils.delete_template(db_row['uuid'])
