@@ -14,10 +14,12 @@
 
 from oslo_log import log as logging
 
-from vitrage.common.constants import VertexProperties as VProps
-from vitrage.datasources import OPENSTACK_CLUSTER
+
 from vitrage_tempest_plugin.tests.api.topology.base import BaseTopologyTest
 from vitrage_tempest_plugin.tests.base import IsEmpty
+from vitrage_tempest_plugin.tests.common.constants import OPENSTACK_CLUSTER
+from vitrage_tempest_plugin.tests.common.constants import VertexProperties as \
+    VProps
 import vitrage_tempest_plugin.tests.utils as utils
 from vitrageclient.exceptions import ClientException
 
@@ -40,16 +42,6 @@ class TestTopology(BaseTopologyTest):
     NUM_INSTANCE = 3
     NUM_VOLUME = 1
 
-    def setUp(self):
-        super(TestTopology, self).setUp()
-
-    def tearDown(self):
-        super(TestTopology, self).tearDown()
-
-    @classmethod
-    def setUpClass(cls):
-        super(TestTopology, cls).setUpClass()
-
     def _get_root_vertex_id(self):
         items = self.vitrage_client.resource.list(
             resource_type=OPENSTACK_CLUSTER, all_tenants=True)
@@ -464,7 +456,7 @@ class TestTopology(BaseTopologyTest):
                 all_tenants=True)
 
             # Test Assertions
-            self.assertEqual({}, api_graph)
+            self.assert_is_empty(api_graph)
         except Exception as e:
             self._handle_exception(e)
             raise
