@@ -12,36 +12,39 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from datetime import datetime
 import json
-from networkx.readwrite import json_graph
 import six
-import sys
-import traceback
 
+from networkx.readwrite import json_graph
 from oslo_log import log as logging
 from oslo_utils import timeutils
 from oslotest import base
 from testtools.matchers import HasLength
 from testtools.matchers import Not
 
-from vitrage.common.constants import EdgeProperties
-from vitrage.common.constants import EntityCategory
-from vitrage.common.constants import VertexProperties as VProps
-from vitrage.datasources.aodh import AODH_DATASOURCE
-from vitrage.datasources.cinder.volume import CINDER_VOLUME_DATASOURCE
-from vitrage.datasources.heat.stack import HEAT_STACK_DATASOURCE
-from vitrage.datasources.neutron.network import NEUTRON_NETWORK_DATASOURCE
-from vitrage.datasources.neutron.port import NEUTRON_PORT_DATASOURCE
-from vitrage.datasources import NOVA_HOST_DATASOURCE
-from vitrage.datasources import NOVA_INSTANCE_DATASOURCE
-from vitrage.datasources import NOVA_ZONE_DATASOURCE
-from vitrage.datasources import OPENSTACK_CLUSTER
-from vitrage.datasources.static_physical import SWITCH
 from vitrage.graph.driver.networkx_graph import NXGraph
 from vitrage.graph import Edge
 from vitrage.graph import Vertex
 from vitrage import service
 
+from vitrage_tempest_plugin.tests.common.constants import AODH_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import \
+    CINDER_VOLUME_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import EdgeProperties
+from vitrage_tempest_plugin.tests.common.constants import EntityCategory
+from vitrage_tempest_plugin.tests.common.constants import HEAT_STACK_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import \
+    NEUTRON_NETWORK_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import \
+    NEUTRON_PORT_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import NOVA_HOST_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import \
+    NOVA_INSTANCE_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import NOVA_ZONE_DATASOURCE
+from vitrage_tempest_plugin.tests.common.constants import OPENSTACK_CLUSTER
+from vitrage_tempest_plugin.tests.common.constants import VertexProperties \
+    as VProps
 from vitrage_tempest_plugin.tests.common import general_utils
 from vitrage_tempest_plugin.tests.common.tempest_clients import TempestClients
 from vitrage_tempest_plugin.tests import utils
@@ -70,19 +73,20 @@ class BaseVitrageTempest(base.BaseTestCase):
     ADMIN_USERNAME = 'admin'
     ADMIN_PROJECT_NAME = 'admin'
 
-    def assert_list_equal(self, l1, l2):
-        if tuple(sys.version_info)[0:2] < (2, 7):
-            # for python 2.6 compatibility
-            self.assertEqual(l1, l2)
-        else:
-            super(BaseVitrageTempest, self).assertListEqual(l1, l2)
+    def assert_list_equal(self, l1, l2, message=None):
+        self.assertListEqual(l1, l2, message)
 
-    def assert_dict_equal(self, d1, d2, message):
-        if tuple(sys.version_info)[0:2] < (2, 7):
-            # for python 2.6 compatibility
-            self.assertEqual(d1, d2)
-        else:
-            super(BaseVitrageTempest, self).assertDictEqual(d1, d2, message)
+    def assert_dict_equal(self, d1, d2, message=None):
+        self.assertDictEqual(d1, d2, message)
+
+    def assert_set_equal(self, s1, s2, message=None):
+        self.assertSetEqual(s1, s2, message)
+
+    def assert_sequence_equal(self, s1, s2, message=None):
+        self.assertSequenceEqual(self, s1, s2, message)
+
+    def assert_tuple_equal(self, s1, s2, message=None):
+        self.assertTupleEqual(self, s1, s2, message)
 
     def assert_timestamp_equal(self, first, second, msg=None):
         """Checks that two timestamps are equals.
@@ -234,7 +238,7 @@ class BaseVitrageTempest(base.BaseTestCase):
 
         # switch
         props = {VProps.VITRAGE_CATEGORY: EntityCategory.RESOURCE,
-                 VProps.VITRAGE_TYPE: SWITCH,
+                 VProps.VITRAGE_TYPE: 'switch',
                  self.NUM_VERTICES_PER_TYPE: kwargs.get(
                      'switch_entities', 0),
                  self.NUM_EDGES_PER_TYPE: kwargs.get(
@@ -302,6 +306,8 @@ class BaseVitrageTempest(base.BaseTestCase):
                              '%s%s' % ('Num vertices is incorrect for: ',
                                        entity[VProps.VITRAGE_TYPE]))
 
+            # TODO(iafek): bug - edges between entities of the same type are
+            # counted twice
             entity_num_edges = sum([len(graph.get_edges(vertex.vertex_id))
                                     for vertex in vertices])
             self.assertEqual(entity[self.NUM_EDGES_PER_TYPE],
@@ -312,6 +318,23 @@ class BaseVitrageTempest(base.BaseTestCase):
         self.assertEqual(num_entities, graph.num_vertices())
         self.assertEqual(num_edges, graph.num_edges())
 
+        self._validate_timestamps(graph)
+
+    def _validate_timestamps(self, graph):
+        self._validate_timestamp(graph, VProps.UPDATE_TIMESTAMP)
+        self._validate_timestamp(graph, VProps.VITRAGE_SAMPLE_TIMESTAMP)
+
+    def _validate_timestamp(self, graph, timestamp_name):
+        for vertex in graph.get_vertices():
+            timestamp = vertex.get(timestamp_name)
+            if timestamp:
+                try:
+                    datetime.strptime(timestamp, utils.TIMESTAMP_FORMAT)
+                except ValueError:
+                    self.fail('Unexpected timestamp format of \'%s\' in: %s\n'
+                              'The format should be: %s' %
+                              (timestamp_name, vertex, utils.TIMESTAMP_FORMAT))
+
     @staticmethod
     def _get_value(item, key):
         return utils.uni2str(item[key])
@@ -329,7 +352,6 @@ class BaseVitrageTempest(base.BaseTestCase):
         LOG.info('Entity Graph: \n%s', json.dumps(node_link_data))
 
     def _handle_exception(self, exception):
-        traceback.print_exc()
         LOG.exception(exception)
         self._print_entity_graph()
 
